/*******************************************************************************
*                                 AMetal
*                       ----------------------------
*                       innovating embedded platform
*
* Copyright (c) 2001-2015 Guangzhou ZHIYUAN Electronics Stock Co., Ltd.
* All rights reserved.
*
* Contact information:
* web site:    http://www.zlg.cn/
* e-mail:      ametal.support@zlg.cn
*******************************************************************************/

/**
 * \file
 * \brief LPC82X WKT ûʵ
 * \sa am_hwconf_lpc82x_wkt.c
 *
 * \internal
 * \par Modification history
 * - 1.01 15-12-02  sky, modified.
 * - 1.00 15-07-08  zxl, first implementation.
 * \endinternal
 */

#include "am_lpc_wkt.h"
#include "am_lpc82x.h"
#include "amhw_lpc82x_clk.h"
#include "amhw_lpc82x_pmu.h"


/**
 * \addtogroup am_if_src_hwconf_wkt
 * \copydoc am_hwconf_lpc82x_wkt.c
 * @{
 */

/** \brief WKTƽ̨ʼ */
static void __lpc82x_wkt_plfm_init (void)
{
    /* ʹWKTʱ */
    amhw_lpc82x_clk_periph_enable(AMHW_LPC82X_CLK_WKT);

    /* λWKT */
    amhw_lpc82x_syscon_periph_reset(AMHW_LPC82X_RESET_WKT);
}

/** \brief WKTƽ̨ʼ */
static void __lpc82x_wkt_plfm_deinit (void)

{    /* λWKT */
    amhw_lpc82x_syscon_periph_reset(AMHW_LPC82X_RESET_WKT);

    /* WKTʱ */
    amhw_lpc82x_clk_periph_disable(AMHW_LPC82X_CLK_WKT);

}

/** \brief WKTƽ̨ʱӽʼ */
static void __lpc82x_wkt_plfm_clk_init (const am_lpc_wkt_devinfo_t *p_devinfo)
{
    amhw_lpc_wkt_t  *p_hw_wkt  = (amhw_lpc_wkt_t *)(p_devinfo->wkt_regbase);

    if (p_devinfo == NULL) {
        return;
    }

    switch (p_devinfo->clksel_str) {
    case AMHW_LPC_WKT_IRC_CLOCK:

        /* WKTʱԴΪڲʱ */
        amhw_lpc_wkt_clksel_cfg(p_hw_wkt, AMHW_LPC_WKT_IRC_CLOCK);

        break;
    case AMHW_LPC_WKT_LOW_POWER_CLOCK:

        /* ʹܵ͹ */
        amhw_lpc82x_pmu_lposcen_enable(AMHW_LPC82X_PMU);

        /* WKTʱԴΪ͹ */
        amhw_lpc_wkt_clksel_cfg(p_hw_wkt, AMHW_LPC_WKT_LOW_POWER_CLOCK);

        break;

    case AMHW_LPC_WKT_EXT_CLOCK:
        /* WAKEUPCLKHYS ųʹ */
        amhw_lpc82x_pmu_wakeupclkhys_enable(AMHW_LPC82X_PMU);

        /* WAKECLKPADʹ(ʹPIO0_28ⲿʱӹ) */
        amhw_lpc82x_pmu_wakeclkpad_enable(AMHW_LPC82X_PMU);

        /* WKTʱԴΪⲿʱ */
        amhw_lpc_wkt_clksel_cfg(p_hw_wkt, AMHW_LPC_WKT_EXT_CLOCK);

        break;

    }

}

/** \brief WKT豸Ϣ */
static const am_lpc_wkt_devinfo_t __g_wkt_devinfo = {
    LPC82X_WKT_BASE,                /**< \brief WKTĴĻַ */
    INUM_WKT,                       /**< \brief WKT жϱ */
    1,                              /**< \brief ֧1ͨ */
    AMHW_LPC_WKT_LOW_POWER_CLOCK,   /**< \brief ѡIRCʱ */
    0,                              /**< \brief ʹⲿʱʱƵ */

    __lpc82x_wkt_plfm_clk_init,     /**< \brief ƽ̨ʱӳʼ */

    __lpc82x_wkt_plfm_init,         /**< \brief WKTƽ̨ʼ */
    __lpc82x_wkt_plfm_deinit        /**< \brief WKTƽ̨ʼ */
};

static am_lpc_wkt_dev_t __g_wkt_dev;     /**< \brief WKT 豸 */


/** \brief WKT ʵʼTimer׼ */
am_timer_handle_t am_lpc82x_wkt_inst_init (void)
{
    return am_lpc_wkt_init(&__g_wkt_dev, &__g_wkt_devinfo);
}

/** \brief WKT ʵʼ */
void am_lpc82x_wkt_inst_deinit (am_timer_handle_t handle)
{
    am_lpc_wkt_deinit(handle);
}

/**
 * @}
 */

/* end of file */
