/*******************************************************************************
*                                 AMetal
*                       ----------------------------
*                       innovating embedded platform
*
* Copyright (c) 2001-2017 Guangzhou ZHIYUAN Electronics Stock Co., Ltd.
* All rights reserved.
*
* Contact information:
* web site:    http://www.zlg.cn/
* e-mail:      ametal.support@zlg.cn
*******************************************************************************/

/**
 * \file
 * \brief The LPC82X interrupt user configure
 * \sa am_hwconf_arm_nvic.c
 *
 * \internal
 * \par Modification history
 * - 1.00 15-01-29  hbt, first implementation.
 * \endinternal
 */

#include "ametal.h"
#include "am_lpc82x.h"
#include "am_arm_nvic.h"

/**
 * \addtogroup am_if_src_hwconf_arm_nvic
 * \copydoc am_hwconf_arm_nvic.c
 * @{
 */

/** \brief ISR information count */
#define __ISRINFO_COUNT    INUM_INTERNAL_COUNT

/** \brief Support interrupt count */
static struct am_arm_nvic_isr_info __nvic_isr_infor[__ISRINFO_COUNT];


/** \brief Interrupt map */
uint8_t __nvic_isr_map[INUM_INTERNAL_COUNT];


/** \brief Interrupt device information */
const am_arm_nvic_devinfo_t __g_nvic_devinfo =
{
    {
        INUM_INTERNAL_MIN,  /**< \brief Interrupt start number */
        INUM_INTERNAL_MAX   /**< \brief Interrupt end number */
    },

    AM_ARM_NVIC_CORE_M0PLUS, /* m0+ں */

#ifdef AM_CORTEX_M4
    /* ȼ3λȼ0λ */
    3,                      /**< \brief ȼλ */
    4,                      /**< \brief ж */
#endif

#ifdef AM_CORTEX_M0
    /*ȼȼ2λ */
    2,                      /**< \brief ȼλ */
    0,                      /**< \brief ж */
#endif

    INUM_INTERNAL_COUNT,    /**< \brief ж */
    __nvic_isr_map,         /**< \brief ISR information map(size equal to input_cnt) */
    __ISRINFO_COUNT,        /**< \brief ISR information count */
    __nvic_isr_infor,       /**< \brief ISR information map memory(size equal to isrinfo_cnt) */

    NULL,                   /**< \brief ƽ̨ʼ */
    NULL                    /**< \brief ƽ̨ȥʼ */
};

/** \brief Interrupt device */
static am_arm_nvic_dev_t __g_nvic_dev;

/**
 * \brief  жʵʼʼж
 */
int am_lpc82x_nvic_inst_init (void)
{
    return am_arm_nvic_init(&__g_nvic_dev, &__g_nvic_devinfo);
}

/**
 * \brief  жʵʼ
 */
void am_lpc82x_nvic_inst_deinit (void)
{
    am_arm_nvic_deinit();
}

/**
 * @}
 */

/* end of file */
