/*******************************************************************************
*                                 AMetal
*                       ----------------------------
*                       innovating embedded platform
*
* Copyright (c) 2001-2015 Guangzhou ZHIYUAN Electronics Stock Co., Ltd.
* All rights reserved.
*
* Contact information:
* web site:    http://www.zlg.cn/
* e-mail:      ametal.support@zlg.cn
*******************************************************************************/

/**
 * \file
 * \brief LPC82X ʱûļ
 * \sa am_hwconf_lpc82x_clk.c
 *
 * \internal
 * \par Modification history
 * - 1.00 15-12-03  lnk, first implementation.
 * \endinternal
 */

#include "am_lpc82x.h"
#include "am_lpc82x_clk.h"
#include "amhw_lpc82x_swm.h"
#include "amhw_lpc82x_iocon.h"
#include "amhw_lpc82x_clk.h"
#include "amhw_lpc82x_syscon.h"

/**
 * \addtogroup am_if_src_hwconf_lpc82x_clk
 * \copydoc am_hwconf_lpc82x_clk.c
 * @{
 */

/**
 * \brief  PLLʱԴ
 *       - ڲIRC12MHz  : AMHW_LPC82X_CLK_PLLIN_SRC_IRC
 *       - ⲿ12MHz : AMHW_LPC82X_CLK_PLLIN_SRC_SYSOSC
 *       - ⲿʱ  : AMHW_LPC82X_CLK_PLLIN_SRC_CLKIN
 * \note ʹڲIRCҪʹⲿҪڿϺ12MHzľ\n
 *       ޸ĺֵΪAMHW_LPC82X_CLK_PLLIN_SRC_SYSOSC,ʹⲿʱ,\n
 *       12MHzʱӴPIO0_1롣
 */
#define __LPC82X_CLK_PLL_SRC  AMHW_LPC82X_CLK_PLLIN_SRC_IRC


/** \brief CLK ƽ̨ʼ */
static void __lpc82x_clk_plfm_init (void)
{
    if(__LPC82X_CLK_PLL_SRC == AMHW_LPC82X_CLK_PLLIN_SRC_SYSOSC) {
        /**
         *  ⲿϵͳΪʱԴ
         */

        /* PIO0_8,PIO0_9 Ϊģʽ*/
        amhw_lpc82x_clk_periph_enable(AMHW_LPC82X_CLK_IOCON);

        amhw_lpc82x_iocon_mode_set(AMHW_LPC82X_IOCON,
                                   PIO0_8,
                                   AMHW_LPC82X_IOCON_MODE_INACTIVE);

        amhw_lpc82x_iocon_mode_set(AMHW_LPC82X_IOCON,
                                   PIO0_9,
                                   AMHW_LPC82X_IOCON_MODE_INACTIVE);

        /* ʹPIO0_8_XTALINPIO0_9_XTALOUT ؾ̶Ź */

        amhw_lpc82x_clk_periph_enable(AMHW_LPC82X_CLK_SWM);

        amhw_lpc82x_swm_fixed_func_enable(AMHW_LPC82X_SWM,
                                          AMHW_LPC82X_SWM_PIO0_8_XTALIN);

        amhw_lpc82x_swm_fixed_func_enable(AMHW_LPC82X_SWM,
                                          AMHW_LPC82X_SWM_PIO0_9_XTALOUT);

        } else if (__LPC82X_CLK_PLL_SRC == AMHW_LPC82X_CLK_PLLIN_SRC_CLKIN) {
        /**
         *  ⲿܽΪʱԴ
         */

        /* PIO0_1 Ϊģʽ*/

        amhw_lpc82x_clk_periph_enable(AMHW_LPC82X_CLK_IOCON);

        amhw_lpc82x_iocon_mode_set(AMHW_LPC82X_IOCON,PIO0_1,
                                   AMHW_LPC82X_IOCON_MODE_INACTIVE);

        /* ʹPIO0_1 ؾ̶Ź CLKIN */

        amhw_lpc82x_clk_periph_enable(AMHW_LPC82X_CLK_SWM);

        amhw_lpc82x_swm_fixed_func_enable(AMHW_LPC82X_SWM,
                                          AMHW_LPC82X_SWM_PIO0_1_CLKIN);
        } else {
        /* ʹڲIRC ʱԴ */
        }

}

/** \brief CLK豸Ϣ
 *  Ĭֵ ðʹڲIRC12MHz), PLLƵʱӣ\n
 *           ʱ main_rate = 60 MHz, ϵͳʱ system_clk = 30MHz
 *
 *  \note ͨ޸__g_clk_devinfomainʱԴƵʣʱ
 *        ʹPLLʱ޸MSEL,PSELʵ֣ϵͳʱʱӷƵõ,
 *        Ĭ2Ƶ
 */
static const am_lpc82x_clk_devinfo_t __g_clk_devinfo =
{
    /**
     * \brief PLL ʱԴ
     *        PLLʱԴʹⲿ
     *        ڲIRC12MHz:    AMHW_LPC82X_CLK_PLLIN_SRC_IRC
     *        ϵͳ12MHz : AMHW_LPC82X_CLK_PLLIN_SRC_SYSOSC
     *        ⲿʱ : AMHW_LPC82X_CLK_PLLIN_SRC_CLKIN
     */
    __LPC82X_CLK_PLL_SRC,

    /**
     * \brief PLL ƼĴMSELʹFCLKOUT ڷΧ 100MHz
     *        FCLKOUT = FCLKIN * (MSEL + 1) = 12MHz * 5 = 60 MHz
     */
    4,

    /**
     * \brief PLL ƼĴPSEL ,ʹFCCO ڷΧ 156 - 320MHz
     *        FCCO = FCLKOUT * 2 * 2^(PSEL) = 60MHz * 2 * 2 = 240MHz
     */
    1,

    /**
     * \brief MAIN ʱԴѡ
     *        - ڲIRC      AMHW_LPC82X_CLK_MAIN_SRC_IRC
     *        - PLL      AMHW_LPC82X_CLK_MAIN_SRC_PLLIN
     *        - Ź AMHW_LPC82X_CLK_MAIN_SRC_WDTOSC
     *        - PLL      AMHW_LPC82X_CLK_MAIN_SRC_PLLOUT
     * \note         main_clk = FCLKOUT = 60MHz
     */
    AMHW_LPC82X_CLK_MAIN_SRC_PLLOUT,

    /**
     * \brief ϵͳʱӷƵ 1- 255 ֵ֮
     *        system_clk = main_clk / div = 60MHz / 2 = 30 MHz
     */
    2,

    /* MAIN ʱԴѡŹʱҪWDTOSCƵʷƵϵƵѡ
     * ΪĬֵ 0.6MHz64ƵʱƵ9.375KHz
     */

    /**
     * \brief WDTOSCƵʷƵϵ 2 - 64 ֮ż
     *
     */
    64,

    /**
     * \brief WDTOSCƵѡ
     *        wdtosc_freq = 600000UL Hz
     */
    AMHW_LPC82X_CLK_WDTOSC_RATE_0_6MHZ,

    /* ƽ̨ʼʱŵȲ */
    __lpc82x_clk_plfm_init,

    /* CLKƽ̨ȥʼ */
    NULL

};

/** \brief ʱ豸ʵ */
static am_lpc82x_clk_dev_t __g_clk_dev;

/**
 * \brief  CLK ʵʼʼϵͳʱ
 * \retval AM_OK : ʱӳɹʼ
 */
int am_lpc82x_clk_inst_init (void)
{
    return am_lpc82x_clk_init(&__g_clk_dev, &__g_clk_devinfo);
}

/**
 * @}
 */

/* end of file */
